# Test data
The test data used here was obtained partially from third parties.

# Index
The folling index provides information about the origin of the given test file:
- ACE_0793-01_MK13.raw (not stored in repository due to size)

    License: Creative Commons Public Domain (CC0)
    
    URL: https://www.ebi.ac.uk/pride/archive/projects/PXD047437

- Angiotensin_325-CID.raw

    License: 2-Clause BSD License

    URL: https://github.com/PNNL-Comp-Mass-Spec/Thermo-Raw-File-Reader/raw/refs/heads/master/UnitTests/Docs/Angiotensin_325-ETD.raw